<?php
/**
 * CourseMst Entity
 * $Id: CourseMst.inc,v 1.1 2020/2/22 11:26:51 Exp $
 * @author zb
 * @package jp.compass.entity
 * @access public
 */
class CourseMst extends CompassDynamicData
{
	var $parent_category_id;
	var $sub_category_id;
	var $title;
	var $front_image;
	var $teacher_name;
	var $teacher_profile;
	var $media_count;
	var $delete_flg;

	/**
	 * 构造实现。course_mst创建实例。
	 * 
	 * @access public
	 * @param mixed course_mst
	 */
	function constructor($record)
	{
		parent::constructor($record);

		$this->parent_category_id = $record["parent_category_id"];
		$this->sub_category_id    = $record["sub_category_id"];
		$this->title              = $record["title"];
		$this->front_image        = $record["front_image"];
		$this->teacher_name       = $record["teacher_name"];
		$this->teacher_profile    = $record["teacher_profile"];
		$this->media_count        = $record["media_count"];
		$this->delete_flg         = $record["delete_flg"];
	}

	/**
	 * 根据条件,获取数据列表。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getList($w_param = null, $orderkey = null, $direction = "ASC", $offset = null, $limit = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}

		return CompassDBHandler::getList("CourseMst", "course_mst", $w_param, $orderkey, $direction, $offset, $limit);
	}

	/**
	 * 根据条件，获取数据列表的件数。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getListCount($w_param = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}
		$db = CompassDBManager::getInstance();
		$result = $db->doSelect("course_mst", $w_param, null, null, null, null, "count(*) as count");

		return $result[0]["count"];
	}

	/**
	 * 获得此类指定ID的实例。
	 */
	public static function getById($id)
	{
		// delete_flg
		$param = array();
		$param["delete_flg"] = false;

		return CompassDBHandler::getById("CourseMst", "course_mst", $id, $param);
	}

	// -- 这里开始Dynamic ---
	/**
	 * 将此实例写入DB。
	 * DynamicData共用的保存方法。
	 * @access public
	 * @return int 写入实例的ID
	 */
	public function save()
	{
		$v_param = array();

		ParamUtil::copyObj2Array($v_param, $this, "parent_category_id");
		ParamUtil::copyObj2Array($v_param, $this, "sub_category_id");
		ParamUtil::copyObj2Array($v_param, $this, "title");
		ParamUtil::copyObj2Array($v_param, $this, "front_image");
		ParamUtil::copyObj2Array($v_param, $this, "teacher_name");
		ParamUtil::copyObj2ArrayNullField($v_param, $this, "teacher_profile");
		ParamUtil::copyObj2Array($v_param, $this, "media_count");
		ParamUtil::copyObj2Array($v_param, $this, "delete_flg");

		// 保存
		parent::_save("course_mst", $v_param);
	}
}